@@ -114,7 +114,7 @@ view_get_type (void)
       {
 	sizeof (GStonesViewClass),
 
-	(GBaseInitFunc) view_init,
+        NULL,
         NULL,
 
 	(GClassInitFunc) view_class_init,
@@ -123,7 +123,7 @@ view_get_type (void)
 
 	sizeof (GStonesView),
         0,
-	NULL,
+	(GInstanceInitFunc) view_init,
         
 	NULL
       };
@@ -515,7 +515,11 @@ atari_scroll (GStonesView *view, GStonesCave *cave)
 
 
 #define MAX_SCROLL_SPEED 0.9
+
+#ifndef abs
 #define abs(i) ((i)>0?(i):-(i))
+#endif
+
 void
 smooth_scroll (GStonesView *view, GStonesCave *cave)
 {
